######## PROJECT: Laboratory experiment: Germination and seedling performance after freezing 
#### PURPOSE:Examine germination success and seedling survival and growth in response to freezing treatments .
#### AUTHOR: Inam Jameel
# AUTHOR: Inam Jameel
#### DATE LAST MODIFIED: 08 Feb 24

# remove objects and clear workspace
rm(list = ls(all=TRUE))


#require packages
require(lme4) #for running linear mixed models
require(ggplot2) #for plotting 
require(visreg) # for plotting
require(car) # to run ANOVA on model output
require(plyr) # for data wrangling
require(dplyr) # for data wrangling
require(tidyr) # for data wrangling
require(effects) # for plotting
require(emmeans) #for plotting
require(glmmTMB) # for running survival model, have to load twice
require(gamlss) # for running phenology model
require(broom.mixed) #for making tables
require(multcomp) #for pairwise comparisons
require(vioplot) #for violin plots
library(DHARMa) #model diagnostics

# set working directory
setwd("/Users/inam/Downloads/GCB_revision/data_scripts") #this is where you specify the folder where you have the data on your computer


#*******************************************************************************
#### 1. Field temperature data and chamber schedule for laboratory experiment #####
#*******************************************************************************

#to plot the air temperature data in the window of snow melt for 2021 for garden located at 2553m

tempdata <-read.csv("Estess20202021_air.csv", header=T)

#filter for temperature during window of snow melt
temp_window <- tempdata %>% filter(order %in% (8477:9548) )

#Figure S1a  line graph of temperature during window of snow melt 
field_plot<- ggplot(data = temp_window) + theme_bw() +
  geom_line(aes(x = order, y = temp)) + scale_x_continuous("Date (2021)",breaks=seq(8477,9548,48),labels=c("Mar 28","29","30","31","Apr 1","2","3","4","5","6","7","8","9","10","11","12","13","14","15","16","17","18","19"))+scale_y_continuous("Temperature (C°)")


#to plot freezing chamber temperature schedule for laboratory experiment

chamber_temp <-read.csv("Laboratory_treatment_schedule.csv", header=T)

chamber_temp$Tmin <- as.factor(chamber_temp$Tmin)


#Figure S1b line graph of treatment levels for laboratory experiment 
lab_plot<-ggplot(data = chamber_temp) +
  geom_line(aes(x = hour, y = Temp, group = Tmin, color = Tmin, linetype = Tmin),linewidth=0.9) + theme_bw()+scale_linetype_manual(values=c("solid", "dashed","dotted","dotdash")) + scale_color_manual(name = "Tmin", values = c("#882255","darkorange","#6699cc","#117733"))+ scale_x_continuous("Hour of schedule ",breaks=seq(0,14,1))+scale_y_continuous("Temperature (C°)") +   theme(legend.position="top")


#combining figures

library(ggpubr)
figureS1 <- ggarrange(field_plot, lab_plot,
                     labels = c("A", "B"),
                     ncol = 1, nrow = 2)
figureS1



#*******************************************************************************
#### 2. Probability of seed germination ####
#*******************************************************************************

#genotypic level

seed_experiment <-read.csv("LaboratoryExp_Seed_genotype.csv", header=T)

sapply(seed_experiment,class)

seed_experiment$genotype<-as.factor(seed_experiment$genotype)

seed_experiment$Tmin<-as.factor(seed_experiment$Tmin)

seed_experiment$Treatment<-as.factor(seed_experiment$treatment)

seed_experiment$Elev100<-seed_experiment$elevation/100 #converts elevation

#Change baseline for the garden factor to reflect increasing garden elevation

seed_experiment $Treatment<-factor(seed_experiment $treatment, levels = c("Control","Negative_five","Negative_ten","Negative_seventeen"))

sapply(seed_experiment,class)

Germ_model<-glmmTMB(cbind(germinated, planted-germinated) ~Elev100*Treatment +(1|genotype) ,data=seed_experiment,family=binomial(link="logit"))

#Use the DHARMa package to examine the residuals, which are ok
simulationOutput <- simulateResiduals(fittedModel= Germ_model, plot = T, re.form = NULL)

Anova(Germ_model,type="III")

# Obtain slopes for each treatment level. These slopes are exponentiated to calculate odds ratios

SeedOdds<- emtrends(Germ_model, specs = c("Treatment"), var = "Elev100")

SeedOdds<- as.data.frame(summary(SeedOdds))[c('Treatment', 'Elev100.trend', 'SE')]

SeedOdds %>% mutate(
  
  OddsRatio = exp(Elev100.trend),
  
  Lower95 = OddsRatio * exp(-1.96*SE),
  
  Upper95 = OddsRatio * exp(1.96*SE))


##Testing the random effect of genotype

#Germ_model_nogeno<-glmmTMB(cbind(germinated, planted-germinated) ~ Elev100*Treatment,data=seed_experiment,family=binomial(link="logit"))

#anova(Germ_model, Germ_model_nogeno)


#Figure 3: probability of germination for laboratory experiment



##Generate the figure

germ <-visreg(Germ_model,"Elev100", by="Treatment",gg=TRUE,  xlab="Source elevation (km)", ylab="Probability of germination", scale="response",partial=TRUE,type="conditional",line=list(col="black"),points=list(col="black"))

germ+ facet_wrap(~Treatment, ncol =4,)+theme_bw()+ theme(text = element_text(size=15),axis.line.x = element_line(colour = "black"),axis.line.y = element_line(colour = "black"), panel.border = element_blank(),panel.grid.major =element_blank(), panel.grid.minor=element_blank())+theme(legend.position="none")

germ <-visreg(Germ_model,"Elev100", by="Treatment",gg=TRUE,  xlab="Source elevation (km)", ylab="Probability of germination", ylim = c(0, 1),scale="response",partial=TRUE,type="conditional",line=list(col="black"),points=list(col="black"))

germ+ facet_wrap(~Treatment, ncol =4,)+theme_bw()+ theme(text = element_text(size=15),axis.line.x = element_line(colour = "black"),axis.line.y = element_line(colour = "black"), panel.border = element_blank(),panel.grid.major =element_blank(), panel.grid.minor=element_blank())+theme(legend.position="none")


#*******************************************************************************
#### 3. Seedling analysis: Survival ####
#*******************************************************************************


seedling_exp <-read.csv("LaboratoryExp_Seedling.csv", header=T)
sapply(seedling_exp,class)

seedling_exp$Elev_km<-seedling_exp$elevation/1000
seedling_exp$Selev<-scale(seedling_exp $elevation ,center=TRUE, scale=TRUE)

seedling_exp$initsize<-scale(seedling_exp $init_size ,center=TRUE, scale=TRUE)
seedling_exp$Genotype<-as.factor(seedling_exp$genotype)
seedling_exp$Tray<-as.factor(seedling_exp$tray)
seedling_exp$leaf<-as.factor(seedling_exp$leaf)
seedling_exp $Treatment<-factor(seedling_exp $treatment, levels = c("Control","Negative_five","Negative_ten","Negative_seventeen"))

#Suvival till end of experiment: proceeding with glmmtmb

Fsurvival_model<-glmmTMB(Final_status ~initsize+Treatment*Selev +(1|Tray)+(1|Genotype),data=seedling_exp, family=binomial)

Anova(Fsurvival_model,type="III")
summary(Fsurvival_model)

summary(glht(Fsurvival_model, linfct = mcp(Treatment = "Tukey")))


#Figure S2a: Seedling survival

seedling_exp $Tmin<-factor(seedling_exp $Tmin, levels = c("4", "-5.7","-10.7", "-17.2"))

vioplot(Final_status ~ Tmin, data= seedling_exp, plotCentre = "point",  pchMed = 23,  horizontal= FALSE,ylim=c(0,1),colMed = "black",colMed2 = c("#117733","#6699cc","darkorange","#882255"), col=c("#117733","#6699cc","darkorange","#882255"), ylab="Probability of seedling survival", xlab="Minimum temperature (°C)")



#*******************************************************************************
#### 5. Seedling analysis: Relative growth rate ####
#*******************************************************************************

seedling_exp <-read.csv("LaboratoryExp_Seedling.csv", header=T)
sapply(seedling_exp,class)

seedling_exp$Elev_km<-seedling_exp$elevation/1000
seedling_exp$Selev<-scale(seedling_exp $elevation ,center=TRUE, scale=TRUE)

seedling_exp$initsize<-scale(seedling_exp $init_size ,center=TRUE, scale=TRUE)
seedling_exp$genotype<-as.factor(seedling_exp$genotype) 
seedling_exp$tray<-as.factor(seedling_exp$tray) #Block 
seedling_exp$leaf<-as.factor(seedling_exp$leaf)#seedling class, two or six leaves
seedling_exp $Treatment<-factor(seedling_exp $treatment, levels = c("Control","Negative_five","Negative_ten","Negative_seventeen"))

RGR <-lmer (RGR_total~ Treatment*Selev+leaf 
            +(1|tray)
            +(1|genotype)
            , data = seedling_exp,
            control=lmerControl(optimizer="bobyqa", optCtrl=list(maxfun=2e7)))

Anova(RGR,type="III")

summary(glht(RGR, linfct = mcp(Treatment = "Tukey")))

#Testing the random effect of genotype

#FRGRnogeno <-lmer (RGR_total~ leaf+Tmin*Selev+(1|Tray), data = seedling,control=lmerControl(optimizer="bobyqa", optCtrl=list(maxfun=2e7)))


#anova(RGR, FRGRnogeno)

##Testing the random effect of block (tray)
#FRGRnoblock <-lmer (RGR_total~ leaf+Tmin*Selev+(1|Genotype), data = seedling,control=lmerControl(optimizer="bobyqa", optCtrl=list(maxfun=2e7)))


#anova(RGR, FRGRnoblock)

#Figure S2b

seedlingRGR<-na.omit(seedling_exp[,c('RGR_total','Tmin','treatment')])

seedlingRGR $Tmin<-factor(seedlingRGR $Tmin, levels = c("4", "-5.7","-10.7"))

vioplot(RGR_total ~ Tmin, data= seedlingRGR, plotCentre = "point",  pchMed = 23,  horizontal= FALSE,colMed = "black",colMed2 = c("#117733","#6699cc","darkorange"), col=c("#117733","#6699cc","darkorange"), ylab="Relative growth rate", xlab="Minimum temperature (°C)")#+stripchart(RGR_total ~ Tmin, data= seedlingRGR,  method = "jitter", col = alpha("black", 0.2), pch=16 ,vertical = TRUE, add = TRUE)





